@@ -174,14 +174,6 @@ static guint signals[LAST_SIGNAL] = { 0 };
 /* Based on http://www.ietf.org/rfc/rfc2812.txt (section 2.3.1) */
 #define IRC_SPECIAL       "_\\[\\]{}\\\\|`^"
 #define IRC_NICK_NAME     "(["ALPHA IRC_SPECIAL"]["ALPHADIGITDASH IRC_SPECIAL"]*)"
-/*   user       =  1*( %x01-09 / %x0B-0C / %x0E-1F / %x21-3F / %x41-FF )
- *                ; any octet except NUL, CR, LF, " " and "@"
- *
- * so technically, like so many other places in IRC, we should be using arrays
- * of bytes here rather than UTF-8 strings. Life: too short. In practice this
- * will always be ASCII.
- */
-#define IRC_USER_NAME     "([^\r\n@ ])+"
 
 /* Based on http://www.ietf.org/rfc/rfc4622.txt (section 2.2)
  * We just exclude invalid characters to avoid ucschars and other redundant
@@ -198,7 +190,6 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 #define ACCOUNT_REGEX_ICQ      "^"ICQ_USER_NAME"$"
 #define ACCOUNT_REGEX_IRC      "^"IRC_NICK_NAME"$"
-#define USERNAME_REGEX_IRC     "^"IRC_USER_NAME"$"
 #define ACCOUNT_REGEX_JABBER   "^"JABBER_USER_NAME"@[^@/]+"
 #define ACCOUNT_REGEX_MSN      "^"MSN_USER_NAME"@"HOST"$"
 #define ACCOUNT_REGEX_YAHOO    "^"YAHOO_USER_NAME"$"
@@ -288,24 +279,26 @@ account_widget_entry_changed_common (EmpathyAccountWidget *self,
 
   if (EMP_STR_EMPTY (str))
     {
-      const gchar *value = NULL;
-
       empathy_account_settings_unset (self->priv->settings, param_name);
 
       if (focus)
         {
-          value = empathy_account_settings_get_string (self->priv->settings,
+          gchar *value;
+
+          value = empathy_account_settings_dup_string (self->priv->settings,
               param_name);
+
           DEBUG ("Unset %s and restore to %s", param_name, value);
           gtk_entry_set_text (entry, value ? value : "");
+          g_free (value);
         }
     }
   else
     {
       DEBUG ("Setting %s to %s", param_name,
           tp_strdiff (param_name, "password") ? str : "***");
-      empathy_account_settings_set_string (self->priv->settings, param_name,
-          str);
+      empathy_account_settings_set (self->priv->settings, param_name,
+          g_variant_new_string (str));
     }
 
   curr_status = empathy_account_settings_parameter_is_valid (
@@ -361,21 +354,21 @@ account_widget_int_changed_cb (GtkWidget *widget,
     {
     case DBUS_TYPE_INT16:
     case DBUS_TYPE_INT32:
-      empathy_account_settings_set_int32 (self->priv->settings, param_name,
-          value);
+      empathy_account_settings_set (self->priv->settings, param_name,
+          g_variant_new_int32 (value));
       break;
     case DBUS_TYPE_INT64:
-      empathy_account_settings_set_int64 (self->priv->settings, param_name,
-          value);
+      empathy_account_settings_set (self->priv->settings, param_name,
+          g_variant_new_int64 (value));
       break;
     case DBUS_TYPE_UINT16:
     case DBUS_TYPE_UINT32:
-      empathy_account_settings_set_uint32 (self->priv->settings, param_name,
-          value);
+      empathy_account_settings_set (self->priv->settings, param_name,
+          g_variant_new_uint32 (value));
       break;
     case DBUS_TYPE_UINT64:
-      empathy_account_settings_set_uint64 (self->priv->settings, param_name,
-          value);
+      empathy_account_settings_set (self->priv->settings, param_name,
+          g_variant_new_uint64 (value));
       break;
     default:
       g_return_if_reached ();
@@ -409,8 +402,8 @@ account_widget_checkbutton_toggled_cb (GtkWidget *widget,
   else
     {
       DEBUG ("Setting %s to %d", param_name, value);
-      empathy_account_settings_set_boolean (self->priv->settings, param_name,
-          value);
+      empathy_account_settings_set (self->priv->settings, param_name,
+          g_variant_new_boolean (value));
     }
 
   empathy_account_widget_changed (self);
@@ -450,7 +443,7 @@ account_widget_combobox_changed_cb (GtkWidget *widget,
   GtkTreeIter iter;
   GtkTreeModel *model;
   const gchar *value;
-  const GValue *v;
+  GVariant *v;
   const gchar *default_value = NULL;
   const gchar *param_name;
 
@@ -463,9 +456,9 @@ account_widget_combobox_changed_cb (GtkWidget *widget,
 
   param_name = g_object_get_data (G_OBJECT (widget), "param_name");
 
-  v = empathy_account_settings_get_default (self->priv->settings, param_name);
-  if (v != NULL)
-    default_value = g_value_get_string (v);
+  v = empathy_account_settings_dup_default (self->priv->settings, param_name);
+  if (v != NULL && g_variant_is_of_type (v, G_VARIANT_TYPE_STRING))
+    default_value = g_variant_get_string (v, NULL);
 
   if (!tp_strdiff (value, default_value))
     {
@@ -475,11 +468,13 @@ account_widget_combobox_changed_cb (GtkWidget *widget,
   else
     {
       DEBUG ("Setting %s to %s", param_name, value);
-      empathy_account_settings_set_string (self->priv->settings, param_name,
-          value);
+      empathy_account_settings_set (self->priv->settings, param_name,
+          g_variant_new_string (value));
     }
 
   empathy_account_widget_changed (self);
+
+  tp_clear_pointer (&v, g_variant_unref);
 }
 
 static void
@@ -576,9 +571,9 @@ empathy_account_widget_setup_widget (EmpathyAccountWidget *self,
     }
   else if (GTK_IS_ENTRY (widget))
     {
-      const gchar *str = NULL;
+      gchar *str;
 
-      str = empathy_account_settings_get_string (self->priv->settings,
+      str = empathy_account_settings_dup_string (self->priv->settings,
           param_name);
       gtk_entry_set_text (GTK_ENTRY (widget), str ? str : "");
 
@@ -609,11 +604,12 @@ empathy_account_widget_setup_widget (EmpathyAccountWidget *self,
         g_signal_connect (widget, "activate",
             G_CALLBACK (account_entry_activated_cb), self);
 
-
       g_signal_connect (widget, "changed",
           G_CALLBACK (account_widget_entry_changed_cb), self);
       g_signal_connect (widget, "map",
           G_CALLBACK (account_widget_entry_map_cb), self);
+
+      g_free (str);
     }
   else if (GTK_IS_TOGGLE_BUTTON (widget))
     {
@@ -631,12 +627,12 @@ empathy_account_widget_setup_widget (EmpathyAccountWidget *self,
     {
       /* The combo box's model has to contain the param value in its first
        * column (as a string) */
-      const gchar *str;
+      gchar *str;
       GtkTreeModel *model;
       GtkTreeIter iter;
       gboolean valid;
 
-      str = empathy_account_settings_get_string (self->priv->settings,
+      str = empathy_account_settings_dup_string (self->priv->settings,
           param_name);
       model = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
 
@@ -659,6 +655,8 @@ empathy_account_widget_setup_widget (EmpathyAccountWidget *self,
           g_free (name);
         }
 
+      g_free (str);
+
       g_signal_connect (widget, "changed",
           G_CALLBACK (account_widget_combobox_changed_cb),
           self);
@@ -728,26 +726,28 @@ accounts_widget_generic_setup (EmpathyAccountWidget *self,
     GtkWidget *grid_common_settings,
     GtkWidget *grid_advanced_settings)
 {
-  TpConnectionManagerParam *params, *param;
+  GList *params, *l;
   guint row_common = 0, row_advanced = 0;
 
-  params = empathy_account_settings_get_tp_params (self->priv->settings);
+  params = empathy_account_settings_dup_tp_params (self->priv->settings);
 
-  for (param = params; param != NULL && param->name != NULL; param++)
+  for (l = params; l != NULL; l = g_list_next (l))
     {
+      TpConnectionManagerParam *param = l->data;
       GtkWidget       *grid_settings;
       guint           row;
       GtkWidget       *widget = NULL;
       gchar           *param_name_formatted;
+      const gchar *dbus_signature;
 
-      if (param->flags & TP_CONN_MGR_PARAM_FLAG_REQUIRED)
+      if (tp_connection_manager_param_is_required (param))
         {
           grid_settings = grid_common_settings;
           row = row_common++;
         }
       else if (self->priv->simple)
         {
-          return;
+          continue;
         }
       else
         {
@@ -755,10 +755,12 @@ accounts_widget_generic_setup (EmpathyAccountWidget *self,
           row = row_advanced++;
         }
 
-      param_name_formatted = account_widget_generic_format_param_name
-        (param->name);
+      param_name_formatted = account_widget_generic_format_param_name (
+          tp_connection_manager_param_get_name (param));
 
-      if (param->dbus_signature[0] == 's')
+      dbus_signature = tp_connection_manager_param_get_dbus_signature (param);
+
+      if (dbus_signature[0] == 's')
         {
           gchar *str;
 
@@ -775,7 +777,8 @@ accounts_widget_generic_setup (EmpathyAccountWidget *self,
           gtk_widget_show (widget);
 
           widget = gtk_entry_new ();
-          if (strcmp (param->name, "account") == 0)
+          if (strcmp (tp_connection_manager_param_get_name (param),
+                "account") == 0)
             {
               g_signal_connect (widget, "realize",
                   G_CALLBACK (gtk_widget_grab_focus),
@@ -788,21 +791,21 @@ accounts_widget_generic_setup (EmpathyAccountWidget *self,
           gtk_widget_show (widget);
         }
       /* int types: ynqiuxt. double type is 'd' */
-      else if (param->dbus_signature[0] == 'y' ||
-          param->dbus_signature[0] == 'n' ||
-          param->dbus_signature[0] == 'q' ||
-          param->dbus_signature[0] == 'i' ||
-          param->dbus_signature[0] == 'u' ||
-          param->dbus_signature[0] == 'x' ||
-          param->dbus_signature[0] == 't' ||
-          param->dbus_signature[0] == 'd')
+      else if (dbus_signature[0] == 'y' ||
+          dbus_signature[0] == 'n' ||
+          dbus_signature[0] == 'q' ||
+          dbus_signature[0] == 'i' ||
+          dbus_signature[0] == 'u' ||
+          dbus_signature[0] == 'x' ||
+          dbus_signature[0] == 't' ||
+          dbus_signature[0] == 'd')
         {
           gchar   *str = NULL;
           gdouble  minint = 0;
           gdouble  maxint = 0;
           gdouble  step = 1;
 
-          switch (param->dbus_signature[0])
+          switch (dbus_signature[0])
             {
             case 'y': minint = G_MININT8;  maxint = G_MAXINT8;   break;
             case 'n': minint = G_MININT16; maxint = G_MAXINT16;  break;
@@ -830,7 +833,7 @@ accounts_widget_generic_setup (EmpathyAccountWidget *self,
               widget, 1, row, 1, 1);
           gtk_widget_show (widget);
         }
-      else if (param->dbus_signature[0] == 'b')
+      else if (dbus_signature[0] == 'b')
         {
           widget = gtk_check_button_new_with_label (param_name_formatted);
           gtk_grid_attach (GTK_GRID (grid_settings),
@@ -840,14 +843,17 @@ accounts_widget_generic_setup (EmpathyAccountWidget *self,
       else
         {
           DEBUG ("Unknown signature for param %s: %s",
-              param_name_formatted, param->dbus_signature);
+              param_name_formatted, dbus_signature);
         }
 
       if (widget)
-        empathy_account_widget_setup_widget (self, widget, param->name);
+        empathy_account_widget_setup_widget (self, widget,
+            tp_connection_manager_param_get_name (param));
 
       g_free (param_name_formatted);
     }
+
+  g_list_free_full (params, (GDestroyNotify) tp_connection_manager_param_free);
 }
 
 static void
@@ -998,8 +1004,8 @@ account_widget_apply_and_log_in (EmpathyAccountWidget *self)
             self->priv->radiobutton_reuse));
 
       DEBUG ("Set register param: %d", !reuse);
-      empathy_account_settings_set_boolean (self->priv->settings, "register",
-          !reuse);
+      empathy_account_settings_set (self->priv->settings, "register",
+          g_variant_new_boolean (!reuse));
     }
 
   g_object_get (self->priv->settings,
@@ -1123,8 +1129,6 @@ account_widget_build_irc (EmpathyAccountWidget *self,
 
   empathy_account_settings_set_regex (self->priv->settings, "account",
       ACCOUNT_REGEX_IRC);
-  empathy_account_settings_set_regex (self->priv->settings, "username",
-      USERNAME_REGEX_IRC);
 
   if (self->priv->simple)
     {
@@ -1217,14 +1221,15 @@ static void
 suffix_id_widget_changed_cb (GtkWidget *entry,
     EmpathyAccountWidget *self)
 {
-  const gchar *account;
+  gchar *account;
 
   g_assert (self->priv->jid_suffix != NULL);
 
   account_widget_entry_changed_common (self, GTK_ENTRY (entry), FALSE);
 
-  account = empathy_account_settings_get_string (self->priv->settings,
+  account = empathy_account_settings_dup_string (self->priv->settings,
       "account");
+
   if (!EMP_STR_EMPTY (account) &&
       !g_str_has_suffix (account, self->priv->jid_suffix))
     {
@@ -1234,12 +1239,14 @@ suffix_id_widget_changed_cb (GtkWidget *entry,
 
       DEBUG ("Change account from '%s' to '%s'", account, tmp);
 
-      empathy_account_settings_set_string (self->priv->settings, "account",
-          tmp);
+      empathy_account_settings_set (self->priv->settings, "account",
+          g_variant_new_string (tmp));
       g_free (tmp);
     }
 
   empathy_account_widget_changed (self);
+
+  g_free (account);
 }
 
 static gchar *
@@ -1259,7 +1266,7 @@ setup_id_widget_with_suffix (EmpathyAccountWidget *self,
     GtkWidget *widget,
     const gchar *suffix)
 {
-  const gchar *str = NULL;
+  gchar *str = NULL;
 
   g_object_set_data_full (G_OBJECT (widget), "param_name",
       g_strdup ("account"), g_free);
@@ -1267,7 +1274,7 @@ setup_id_widget_with_suffix (EmpathyAccountWidget *self,
   g_assert (self->priv->jid_suffix == NULL);
   self->priv->jid_suffix = g_strdup (suffix);
 
-  str = empathy_account_settings_get_string (self->priv->settings, "account");
+  str = empathy_account_settings_dup_string (self->priv->settings, "account");
   if (str != NULL)
     {
       gchar *tmp;
@@ -1275,6 +1282,7 @@ setup_id_widget_with_suffix (EmpathyAccountWidget *self,
       tmp = remove_jid_suffix (self, str);
       gtk_entry_set_text (GTK_ENTRY (widget), tmp);
       g_free (tmp);
+      g_free (str);
     }
 
   self->priv->param_account_widget = widget;
@@ -1819,7 +1827,7 @@ static void
 add_register_buttons (EmpathyAccountWidget *self,
     TpAccount *account)
 {
-  const TpConnectionManagerProtocol *protocol;
+  TpProtocol *protocol;
   GtkWidget *radiobutton_register;
 
   if (!self->priv->creating_account)
@@ -1829,7 +1837,7 @@ add_register_buttons (EmpathyAccountWidget *self,
   if (protocol == NULL)
     return;
 
-  if (!tp_connection_manager_protocol_can_register (protocol))
+  if (!tp_protocol_can_register (protocol))
     return;
 
   if (account_widget_get_service (self) != NO_SERVICE)
@@ -1875,7 +1883,9 @@ account_settings_password_retrieved_cb (GObject *object,
     gpointer user_data)
 {
   EmpathyAccountWidget *self = user_data;
-  const gchar *password = empathy_account_settings_get_string (
+  gchar *password;
+
+  password = empathy_account_settings_dup_string (
       self->priv->settings, "password");
 
   if (password != NULL)
@@ -1892,6 +1902,8 @@ account_settings_password_retrieved_cb (GObject *object,
   gtk_toggle_button_set_active (
       GTK_TOGGLE_BUTTON (self->priv->remember_password_widget),
       !EMP_STR_EMPTY (password));
+
+  g_free (password);
 }
 
 static void
@@ -1976,10 +1988,14 @@ do_constructed (GObject *obj)
         }
       else
         {
+          gchar *password;
+
+          password = empathy_account_settings_dup_string (self->priv->settings,
+              "password");
+
           gtk_toggle_button_set_active (
               GTK_TOGGLE_BUTTON (self->priv->remember_password_widget),
-              !EMP_STR_EMPTY (empathy_account_settings_get_string (
-                      self->priv->settings, "password")));
+              !EMP_STR_EMPTY (password));
 
           /* The password might not have been retrieved from the
            * keyring yet. We should update the remember password
@@ -1987,6 +2003,8 @@ do_constructed (GObject *obj)
           tp_g_signal_connect_object (self->priv->settings,
               "password-retrieved",
               G_CALLBACK (account_settings_password_retrieved_cb), self, 0);
+
+          g_free (password);
         }
 
       g_signal_connect (self->priv->remember_password_widget, "toggled",
@@ -2224,12 +2242,12 @@ empathy_account_widget_new_for_protocol (EmpathyAccountSettings *settings,
 gchar *
 empathy_account_widget_get_default_display_name (EmpathyAccountWidget *self)
 {
-  const gchar *login_id;
+  gchar *login_id;
   const gchar *protocol, *p;
   gchar *default_display_name;
   Service service;
 
-  login_id = empathy_account_settings_get_string (self->priv->settings,
+  login_id = empathy_account_settings_dup_string (self->priv->settings,
       "account");
   protocol = empathy_account_settings_get_protocol (self->priv->settings);
   service = account_widget_get_service (self);
@@ -2283,6 +2301,8 @@ empathy_account_widget_get_default_display_name (EmpathyAccountWidget *self)
       default_display_name = g_strdup (_("New account"));
     }
 
+  g_free (login_id);
+
   return default_display_name;
 }
 
