@@ -87,7 +87,7 @@ TpAccount *empathy_account_settings_get_account (
 gboolean empathy_account_settings_has_account (
     EmpathyAccountSettings *settings, TpAccount *account);
 
-TpConnectionManagerParam *empathy_account_settings_get_tp_params (
+GList * empathy_account_settings_dup_tp_params (
     EmpathyAccountSettings *settings);
 
 gboolean empathy_account_settings_have_tp_param (
@@ -100,21 +100,18 @@ void empathy_account_settings_unset (EmpathyAccountSettings *settings,
 void empathy_account_settings_discard_changes (
     EmpathyAccountSettings *settings);
 
-const GValue *empathy_account_settings_get (EmpathyAccountSettings *settings,
-  const gchar *param);
-
 const gchar *
 empathy_account_settings_get_dbus_signature (EmpathyAccountSettings *setting,
   const gchar *param);
 
-const GValue *
-empathy_account_settings_get_default (EmpathyAccountSettings *settings,
+GVariant *
+empathy_account_settings_dup_default (EmpathyAccountSettings *settings,
   const gchar *param);
 
-const gchar *empathy_account_settings_get_string (
+gchar * empathy_account_settings_dup_string (
     EmpathyAccountSettings *settings,
     const gchar *param);
-const gchar * const * empathy_account_settings_get_strv (
+GStrv empathy_account_settings_dup_strv (
     EmpathyAccountSettings *settings,
     const gchar *param);
 
@@ -129,22 +126,9 @@ guint64 empathy_account_settings_get_uint64 (EmpathyAccountSettings *settings,
 gboolean empathy_account_settings_get_boolean (EmpathyAccountSettings *settings,
     const gchar *param);
 
-void empathy_account_settings_set_string (EmpathyAccountSettings *settings,
-    const gchar *param, const gchar *value);
-void empathy_account_settings_set_strv (EmpathyAccountSettings *settings,
-    const gchar *param, gchar **value);
-
-void empathy_account_settings_set_int32 (EmpathyAccountSettings *settings,
-    const gchar *param, gint32 value);
-void empathy_account_settings_set_int64 (EmpathyAccountSettings *settings,
-    const gchar *param, gint64 value);
-void empathy_account_settings_set_uint32 (EmpathyAccountSettings *settings,
-    const gchar *param, guint32 value);
-void empathy_account_settings_set_uint64 (EmpathyAccountSettings *settings,
-    const gchar *param, guint64 value);
-
-void empathy_account_settings_set_boolean (EmpathyAccountSettings *settings,
-    const gchar *param, gboolean value);
+void empathy_account_settings_set (EmpathyAccountSettings *settings,
+    const gchar *param,
+    GVariant *v);
 
 gchar *empathy_account_settings_get_icon_name (
   EmpathyAccountSettings *settings);
@@ -194,7 +178,7 @@ gboolean empathy_account_settings_parameter_is_valid (
 
 gboolean empathy_account_settings_is_valid (EmpathyAccountSettings *settings);
 
-const TpConnectionManagerProtocol * empathy_account_settings_get_tp_protocol (
+TpProtocol * empathy_account_settings_get_tp_protocol (
     EmpathyAccountSettings *settings);
 
 gboolean empathy_account_settings_supports_sasl (EmpathyAccountSettings *self);
